Description: install in $vendorarchdir according to Debian Ruby Policy
Origin: vendor
Last-Update: 2013-10-16

--- a/ext/extconf.rb
+++ b/ext/extconf.rb
@@ -243,7 +243,7 @@
 end
 
 #narray_config = dir_config("narray")
-narray_config = dir_config('narray',$sitearchdir,$sitearchdir)
+narray_config = dir_config('narray',$vendorarchdir,$vendorarchdir)
 # Try to find narray with RubyGems
 begin
   require 'rubygems'
@@ -262,7 +262,7 @@
   end
 end
 
-tamu_anova_config = dir_config('tamu_anova',$sitearchdir,$sitearchdir)
+tamu_anova_config = dir_config('tamu_anova',$vendorarchdir,$vendorarchdir)
 have_tamu_anova_h = have_header("tamu_anova/tamu_anova.h")
 if tamu_anova_config
   have_library("tamuanova")
