Index: ruby-gsl/ext/matrix_complex.c
===================================================================
--- ruby-gsl.orig/ext/matrix_complex.c	2011-06-05 20:42:48.000000000 +0900
+++ ruby-gsl/ext/matrix_complex.c	2011-06-05 20:43:12.000000000 +0900
@@ -1520,7 +1520,7 @@
 }
 
 
-static int gsl_matrix_complex_equal(const gsl_matrix_complex *m1,
+static int gsl_matrix_complex_equal_eps(const gsl_matrix_complex *m1,
   const gsl_matrix_complex *m2, double eps)
 {
   gsl_complex z1, z2;
@@ -1555,7 +1555,7 @@
   Data_Get_Struct(obj, gsl_matrix_complex, m1);
   CHECK_MATRIX_COMPLEX(argv[0]);
   Data_Get_Struct(argv[0], gsl_matrix_complex, m2);
-  ret = gsl_matrix_complex_equal(m1, m2, eps);
+  ret = gsl_matrix_complex_equal_eps(m1, m2, eps);
   if (ret == 1) return Qtrue;
   else return Qfalse;
 }
