Index: ruby-gsl/ext/vector_complex.c
===================================================================
--- ruby-gsl.orig/ext/vector_complex.c	2011-06-05 20:41:34.000000000 +0900
+++ ruby-gsl/ext/vector_complex.c	2011-06-05 20:42:13.000000000 +0900
@@ -1986,7 +1986,7 @@
   return ary;
 }
 
-static int gsl_vector_complex_equal(const gsl_vector_complex *v1,
+static int gsl_vector_complex_equal_eps(const gsl_vector_complex *v1,
   const gsl_vector_complex *v2, double eps)
 {
   gsl_complex z1, z2;
@@ -2019,7 +2019,7 @@
   Data_Get_Struct(obj, gsl_vector_complex, v1);
   CHECK_VECTOR_COMPLEX(argv[0]);
   Data_Get_Struct(argv[0], gsl_vector_complex, v2);
-  ret = gsl_vector_complex_equal(v1, v2, eps);
+  ret = gsl_vector_complex_equal_eps(v1, v2, eps);
   if (ret == 1) return Qtrue;
   else return Qfalse;
 }
